import * as React from 'react';

// Axes
import { IgrAssigningCategoryStyleEventArgs, IgrCategorySeries, IgrCategoryYAxis } from 'igniteui-react-charts';
import { IgrNumericXAxis } from 'igniteui-react-charts';

// Series
import { IgrBarSeries } from 'igniteui-react-charts';

// Data chart modules
import { IgrDataChart } from 'igniteui-react-charts';
import { IgrDataChartCoreModule } from 'igniteui-react-charts';
import { IgrDataChartCategoryModule } from 'igniteui-react-charts';

IgrDataChartCoreModule.register();
IgrDataChartCategoryModule.register();

export default class MyDataChart extends React.Component {
    public data: any[];

    constructor(props: any) {
        super(props);

        this.data = [
            {"Subject": "Literature", "Score": 70 },
            {"Subject": "Math", "Score": 90 },
            {"Subject": "Foreign Language", "Score": 83 },
            {"Subject": "Social Studies", "Score": 40 },
            {"Subject": "Science", "Score": 85 },
        ];
    }

    onAssigningCategoryStyle = (s: IgrCategorySeries, e: IgrAssigningCategoryStyleEventArgs) => {
        if(e.getItems(e.startIndex, e.endIndex)[0].Score >= 80){
            e.fill = "lightgreen";
            e.stroke = "green";
        }
        else if(e.getItems(e.startIndex, e.endIndex)[0].Score >= 50){
            e.fill = "lightyellow";
            e.stroke = "yellow";
        }
        else {
            e.fill = "pink";
            e.stroke = "red";
        }

    }

    public render() {
      return(
          <div style={{margin: "1em"}}>
            <IgrDataChart
              dataSource={this.data}
              width="100%"
              height="300px">
              {/* Axes */}
              <IgrNumericXAxis  name="xAxis" minimumValue="0" maximumValue="100" />
              <IgrCategoryYAxis name="yAxis" label="Subject" />
              {/* Series */}
              <IgrBarSeries
                name="series1"
                xAxisName="xAxis"
                yAxisName="yAxis"
                valueMemberPath="Score"
                isCustomCategoryStyleAllowed="true"
                assigningCategoryStyle={this.onAssigningCategoryStyle} />
              </IgrDataChart>
            </div>
        );
    }
}